@@ -9,11 +9,21 @@
  * -----------------------------------------------
  * Peter Harvey		- pharvey@codebydesign.com
  **************************************************/
+#ifdef QT_V4LAYOUT
+#include <Qt/qapplication.h>
+#include <Qt/qdir.h>
+#else
 #include <qapp.h>
-#include <stdlib.h>
 #include <qdir.h>
+#endif
 
+#include <stdlib.h>
+
+#ifdef QT_V4LAYOUT
+#include "classDataManager4.h"
+#else
 #include "classDataManager.h"
+#endif
 
 int main( int argc, char **argv )
 {
