@@ -14,13 +14,21 @@
 
 #include "classNode.h"
 #include "classCanvas.h"
+#ifdef QT_V4LAYOUT
+#include <Qt/q3listview.h>
+#else
 #include <qlistview.h>
+#endif
 #include <sqlext.h>
 
 class classColumn: public classNode
 {
 public:
+#ifdef QT_V4LAYOUT
+    classColumn( Q3ListViewItem  *pParent, Q3ListViewItem *pAfter, classCanvas *pCanvas, SQLHDBC hDbc, const char *pszName = 0, const char *pszType = 0, const char *pszDesc = 0 );
+#else
     classColumn( QListViewItem  *pParent, QListViewItem *pAfter, classCanvas *pCanvas, SQLHDBC hDbc, const char *pszName = 0, const char *pszType = 0, const char *pszDesc = 0 );
+#endif
    ~classColumn() {}
 };
 #endif
