@@ -12,6 +12,22 @@
 #ifndef classISQL_included
 #define classISQL_included
 
+#ifdef QT_V4LAYOUT
+#include <Qt/qwidget.h>
+#include <Qt/qmenubar.h>
+#include <Qt/q3combobox.h>
+#include <Qt/qslider.h>
+#include <Qt/qtabbar.h>
+#include <Qt/qlabel.h>
+#include <Qt/qfile.h>
+#include <Qt/qfiledialog.h>
+#include <Qt/qtextstream.h>
+#include <Qt/q3valuelist.h>
+#include <Qt/q3multilineedit.h>
+#include <Qt/qlayout.h>
+#include <Qt/qstring.h>
+#include <Qt/q3memarray.h>
+#else
 #include <qwidget.h>
 #include <qmenubar.h>
 #include <qcombo.h>
@@ -30,6 +46,7 @@
 #include <qlayout.h>
 #include <qstring.h>
 #include <qarray.h>
+#endif
 
 #include <sqlext.h>
 
@@ -66,19 +83,31 @@ protected slots:
 protected:
     QTabBar *           pTabBar;
     QSlider *           pSliderRecentSQL;
+#ifdef QT_V4LAYOUT
+    Q3MultiLineEdit *    txtSQL;
+    Q3MultiLineEdit *    txtResults;
+    Q3ListBox *          listStatus;
+    Q3ValueList<QString> listSQL;
+#else
     QMultiLineEdit *    txtSQL;
     QMultiLineEdit *    txtResults;
     QListBox *          listStatus;
+    QValueList<QString> listSQL;
+#endif
     SQLHDBC             hDbc;
     QString             qsDataSource;
     QString             qsResultsFileName;
     QString             qsSQLFileName;
-    QValueList<QString> listSQL;
     int                 nSQL;
 
 private:
+#ifdef QT_V4LAYOUT
+    void getResultsHeader( SQLHSTMT hStmt, SWORD nColumns, QString &qsHorizSep, Q3MemArray<int> &colWidths );
+    int getResultsBody( SQLHSTMT hStmt, SWORD nColumns, const QString &qsHorizSep, const Q3MemArray<int> &colWidths );
+#else
     void getResultsHeader( SQLHSTMT hStmt, SWORD nColumns, QString &qsHorizSep, QArray<int> &colWidths );
     int getResultsBody( SQLHSTMT hStmt, SWORD nColumns, const QString &qsHorizSep, const QArray<int> &colWidths );
+#endif
     void appendHistoryItem();
     void addStatus( const QString &statusMsg ) ;
 };
