@@ -27,9 +27,25 @@
  *
  **********************************************************************
  *
- * $Id: SQLColAttributesW.c,v 1.8 2002/12/05 17:44:30 lurcher Exp $
+ * $Id: SQLColAttributesW.c,v 1.12 2008/08/29 08:01:38 lurcher Exp $
  *
  * $Log: SQLColAttributesW.c,v $
+ * Revision 1.12  2008/08/29 08:01:38  lurcher
+ * Alter the way W functions are passed to the driver
+ *
+ * Revision 1.11  2007/02/28 15:37:47  lurcher
+ * deal with drivers that call internal W functions and end up in the driver manager. controlled by the --enable-handlemap configure arg
+ *
+ * Revision 1.10  2004/11/22 17:02:48  lurcher
+ * Fix unicode/ansi conversion in the SQLGet functions
+ *
+ * Revision 1.9  2003/10/30 18:20:45  lurcher
+ *
+ * Fix broken thread protection
+ * Remove SQLNumResultCols after execute, lease S4/S% to driver
+ * Fix string overrun in SQLDriverConnect
+ * Add initial support for Interix
+ *
  * Revision 1.8  2002/12/05 17:44:30  lurcher
  *
  * Display unknown return values in return logging
@@ -109,6 +125,39 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                     LOG_INFO, 
                     "Error: SQL_INVALID_HANDLE" );
 
+#ifdef WITH_HANDLE_REDIRECT
+		{
+			DMHSTMT parent_statement;
+
+			parent_statement = find_parent_handle( statement, SQL_HANDLE_STMT );
+
+			if ( parent_statement ) {
+        		dm_log_write( __FILE__, 
+                	__LINE__, 
+                    	LOG_INFO, 
+                    	LOG_INFO, 
+                    	"Info: found parent handle" );
+
+				if ( CHECK_SQLCOLATTRIBUTEW( parent_statement -> connection ))
+				{
+        			dm_log_write( __FILE__, 
+                		__LINE__, 
+                   		 	LOG_INFO, 
+                   		 	LOG_INFO, 
+                   		 	"Info: calling redirected driver function" );
+
+            		return  SQLCOLATTRIBUTEW( parent_statement -> connection,
+							statement_handle,
+                    		column_number,
+                    		field_identifier,
+                    		character_attribute,
+                    		buffer_length,
+                    		string_length,
+                    		numeric_attribute );
+				}
+			}
+		}
+#endif
         return SQL_INVALID_HANDLE;
     }
 
@@ -156,9 +205,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 statement -> connection -> environment -> requested_version,
                 SQL_API_SQLCOLATTRIBUTES );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
 
 	/*
@@ -179,9 +226,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 ERROR_07009, NULL,
                 statement -> connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
 	*/
 
@@ -200,9 +245,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 ERROR_HY010, NULL,
                 statement -> connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
     else if ( statement -> state == STATE_S2 &&
             field_identifier != SQL_DESC_COUNT )
@@ -217,9 +260,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 ERROR_07005, NULL,
                 statement -> connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
     else if ( statement -> state == STATE_S4 )
     {
@@ -233,9 +274,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 ERROR_24000, NULL,
                 statement -> connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
     else if ( statement -> state == STATE_S8 ||
             statement -> state == STATE_S9 ||
@@ -251,9 +290,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 ERROR_HY010, NULL,
                 statement -> connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_STMT, statement );
-
-        return function_return( statement, SQL_ERROR );
+        return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
     }
 
     if ( statement -> state == STATE_S11 ||
@@ -271,13 +308,13 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                     ERROR_HY010, NULL,
                     statement -> connection -> environment -> requested_version );
 
-            thread_release( SQL_HANDLE_STMT, statement );
-
-            return function_return( statement, SQL_ERROR );
+            return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
         }
     }
 
-    if ( statement -> connection -> unicode_driver )
+    if ( statement -> connection -> unicode_driver || 
+			    CHECK_SQLCOLATTRIBUTESW( statement -> connection ) || 
+			    CHECK_SQLCOLATTRIBUTEW( statement -> connection ))
     {
         if ( !CHECK_SQLCOLATTRIBUTESW( statement -> connection ))
         {
@@ -310,9 +347,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                         ERROR_IM001, NULL,
                         statement -> connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_STMT, statement );
-
-                return function_return( statement, SQL_ERROR );
+                return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
             }
         }
         else
@@ -398,6 +433,10 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                     {
                         free( as1 );
                     }
+					if ( SQL_SUCCEEDED( ret ) && string_length )
+					{
+						*string_length *= sizeof( SQLWCHAR );
+					}
                     break;
 
                   default:
@@ -416,9 +455,7 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                         ERROR_IM001, NULL,
                         statement -> connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_STMT, statement );
-
-                return function_return( statement, SQL_ERROR );
+                return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
             }
         }
         else
@@ -445,7 +482,6 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                     as1 = malloc( buffer_length + 1 );
                 }
                 break;
-                break;
 
               default:
                 break;
@@ -478,11 +514,14 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 {
                     ansi_to_unicode_copy( character_attribute, (char*) as1, SQL_NTS, statement -> connection );
                 }
-
                 if ( as1 ) 
                 {
                     free( as1 );
                 }
+				if ( SQL_SUCCEEDED( ret ) && string_length && character_attribute )
+				{
+					*string_length *= sizeof( SQLWCHAR );
+				}
                 break;
 
               default:
@@ -545,7 +584,5 @@ SQLRETURN SQLColAttributesW( SQLHSTMT statement_handle,
                 statement -> msg );
     }
 
-    thread_release( SQL_HANDLE_STMT, statement );
-
-    return function_return( statement, ret );
+    return function_return( SQL_HANDLE_STMT, statement, ret );
 }
