@@ -27,9 +27,22 @@
  *
  **********************************************************************
  *
- * $Id: SQLConnectW.c,v 1.11 2002/12/20 11:36:46 lurcher Exp $
+ * $Id: SQLConnectW.c,v 1.14 2008/09/29 14:02:44 lurcher Exp $
  *
  * $Log: SQLConnectW.c,v $
+ * Revision 1.14  2008/09/29 14:02:44  lurcher
+ * Fix missing dlfcn group option
+ *
+ * Revision 1.13  2007/02/28 15:37:47  lurcher
+ * deal with drivers that call internal W functions and end up in the driver manager. controlled by the --enable-handlemap configure arg
+ *
+ * Revision 1.12  2003/10/30 18:20:45  lurcher
+ *
+ * Fix broken thread protection
+ * Remove SQLNumResultCols after execute, lease S4/S% to driver
+ * Fix string overrun in SQLDriverConnect
+ * Add initial support for Interix
+ *
  * Revision 1.11  2002/12/20 11:36:46  lurcher
  *
  * Update DMEnvAttr code to allow setting in the odbcinst.ini entry
@@ -131,6 +144,40 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                     LOG_INFO, 
                     "Error: SQL_INVALID_HANDLE" );
 
+#ifdef WITH_HANDLE_REDIRECT
+		{
+			DMHDBC parent_connection;
+
+			parent_connection = find_parent_handle( connection, SQL_HANDLE_DBC );
+
+			if ( parent_connection ) {
+        		dm_log_write( __FILE__, 
+                	__LINE__, 
+                    	LOG_INFO, 
+                    	LOG_INFO, 
+                    	"Info: found parent handle" );
+
+				if ( CHECK_SQLCONNECTW( parent_connection ))
+				{
+        			dm_log_write( __FILE__, 
+                		__LINE__, 
+                   		 	LOG_INFO, 
+                   		 	LOG_INFO, 
+                   		 	"Info: calling redirected driver function" );
+
+					return SQLCONNECTW( parent_connection, 
+							connection_handle, 
+							server_name, 
+							name_length1,
+							user_name,
+							name_length2,
+							authentication,
+							name_length3 );
+				}
+			}
+		}
+#endif
+
         return SQL_INVALID_HANDLE;
     }
 
@@ -172,9 +219,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                 ERROR_HY090, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     /*
@@ -192,9 +237,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                 ERROR_08002, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     if ( name_length1 && server_name )
@@ -215,9 +258,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                         ERROR_HY090, NULL,
                         connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
             }
         }
         else
@@ -236,9 +277,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                         ERROR_HY090, NULL,
                         connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
             }
         }
         memcpy( dsn, server_name, sizeof( dsn[ 0 ] ) * len );
@@ -256,9 +295,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                 ERROR_IM010, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
     else
     {
@@ -274,7 +311,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
 
     connection -> pooled_connection = NULL;
 
-    unicode_to_ansi_copy((char*) ansi_dsn, dsn, sizeof( ansi_dsn ),  NULL );
+    unicode_to_ansi_copy((char*) ansi_dsn, sizeof( ansi_dsn ), dsn, sizeof( ansi_dsn ),  NULL );
 
     if ( !__find_lib_name((char*) ansi_dsn, lib_name, driver_name ))
     {
@@ -294,9 +331,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                     ERROR_IM002, NULL,
                     connection -> environment -> requested_version );
 
-            thread_release( SQL_HANDLE_DBC, connection );
-
-            return function_return( connection, SQL_ERROR );
+            return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
         }
     }
 
@@ -312,8 +347,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
 
     if ( !__connect_part_one( connection, lib_name, driver_name, &warnings ))
     {
-        thread_release( SQL_HANDLE_DBC, connection );
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     if ( !CHECK_SQLCONNECTW( connection ) &&
@@ -330,9 +364,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                 ERROR_IM001, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     if ( CHECK_SQLCONNECTW( connection ))
@@ -361,17 +393,17 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
         if ( user_name )
         {
             if ( name_length2 == SQL_NTS )
-                unicode_to_ansi_copy((char*) ansi_user, user_name, sizeof( ansi_user ), connection);
+                unicode_to_ansi_copy((char*) ansi_user, sizeof( ansi_user ),user_name, sizeof( ansi_user ), connection);
             else
-                unicode_to_ansi_copy((char*) ansi_user, user_name, name_length2, connection );
+                unicode_to_ansi_copy((char*) ansi_user, sizeof( ansi_user ),user_name, name_length2, connection );
         }
 
         if ( authentication )
         {
             if ( name_length3 == SQL_NTS )
-                unicode_to_ansi_copy((char*) ansi_pwd, authentication, sizeof( ansi_pwd ), connection);
+                unicode_to_ansi_copy((char*) ansi_pwd, sizeof( ansi_pwd ), authentication, sizeof( ansi_pwd ), connection);
             else
-                unicode_to_ansi_copy((char*) ansi_pwd, authentication, name_length3, connection );
+                unicode_to_ansi_copy((char*) ansi_pwd, sizeof( ansi_pwd ), authentication, name_length3, connection );
         }
 
         /*
@@ -579,9 +611,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
         {
             __disconnect_part_one( connection );
 
-            thread_release( SQL_HANDLE_DBC, connection );
-
-            return function_return( connection, ret_from_connect );
+            return function_return( SQL_HANDLE_DBC, connection, ret_from_connect );
         }
     }
 
@@ -617,9 +647,7 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
 
         connection -> state = STATE_C3;
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     if ( log_info.log_flag ) 
@@ -635,12 +663,10 @@ SQLRETURN SQLConnectW( SQLHDBC connection_handle,
                 connection -> msg );
     }
 
-    thread_release( SQL_HANDLE_DBC, connection );
-
     if ( warnings && ret_from_connect == SQL_SUCCESS )
     {
         ret_from_connect = SQL_SUCCESS_WITH_INFO;
     }
 
-    return function_return( connection, ret_from_connect );
+    return function_return( SQL_HANDLE_DBC, connection, ret_from_connect );
 }
