@@ -27,9 +27,33 @@
  *
  **********************************************************************
  *
- * $Id: SQLFreeHandle.c,v 1.4 2002/09/18 14:49:32 lurcher Exp $
+ * $Id: SQLFreeHandle.c,v 1.10 2007/12/17 13:13:03 lurcher Exp $
  *
  * $Log: SQLFreeHandle.c,v $
+ * Revision 1.10  2007/12/17 13:13:03  lurcher
+ * Fix a couple of descriptor typo's
+ *
+ * Revision 1.9  2007/01/02 10:27:50  lurcher
+ * Fix descriptor leak with unicode only driver
+ *
+ * Revision 1.8  2006/04/18 10:24:47  lurcher
+ * Add a couple of changes from Mark Vanderwiel
+ *
+ * Revision 1.7  2003/10/30 18:20:45  lurcher
+ *
+ * Fix broken thread protection
+ * Remove SQLNumResultCols after execute, lease S4/S% to driver
+ * Fix string overrun in SQLDriverConnect
+ * Add initial support for Interix
+ *
+ * Revision 1.6  2003/05/14 09:42:25  lurcher
+ *
+ * Fix bug in stats collection
+ *
+ * Revision 1.5  2003/04/09 08:42:18  lurcher
+ *
+ * Allow setting of odbcinstQ lib from odbcinst.ini and Environment
+ *
  * Revision 1.4  2002/09/18 14:49:32  lurcher
  *
  * DataManagerII additions and some more threading fixes
@@ -149,7 +173,7 @@
 #include <uodbc_stats.h>
 #endif
 
-static char const rcsid[]= "$RCSfile: SQLFreeHandle.c,v $ $Revision: 1.4 $";
+static char const rcsid[]= "$RCSfile: SQLFreeHandle.c,v $ $Revision: 1.10 $";
 
 SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
         SQLHANDLE handle )
@@ -208,9 +232,9 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         ERROR_HY010, NULL,
                         environment -> requested_version );
 
-                thread_release( SQL_HANDLE_ENV, environment );
+            	thread_release( SQL_HANDLE_ENV, environment );
 
-                return function_return( environment, SQL_ERROR );
+                return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
             }
 
             thread_release( SQL_HANDLE_ENV, environment );
@@ -228,6 +252,7 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
             /*
              * check connection
              */
+
             if ( !__validate_dbc( connection ))
             {
                 dm_log_write( __FILE__, 
@@ -274,9 +299,9 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         ERROR_HY010, NULL,
                         connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_ENV, environment);
+            	thread_release( SQL_HANDLE_ENV, environment );
 
-                return function_return( environment, SQL_ERROR );
+                return function_return( SQL_HANDLE_ENV, environment, SQL_ERROR );
             }
 
             environment -> connection_count --;
@@ -308,7 +333,7 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         environment -> msg );
             }
 #if defined ( COLLECT_STATS ) && defined( HAVE_SYS_SEM_H )
-            uodbc_update_stats(environment->sh, UODBC_STATS_TYPE_HDESC,
+            uodbc_update_stats(environment->sh, UODBC_STATS_TYPE_HDBC,
                                (void *)-1);
 #endif
 
@@ -378,8 +403,8 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                           statement -> connection -> environment -> requested_version );
 
                 thread_release( SQL_HANDLE_STMT, statement );
-
-                return function_return( statement, SQL_ERROR );
+				
+                return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
             }
 
             if ( !CHECK_SQLFREEHANDLE( statement -> connection ))
@@ -396,9 +421,7 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                             ERROR_IM001, NULL,
                             statement -> connection -> environment -> requested_version );
 
-                    thread_release( SQL_HANDLE_STMT, statement );
-
-                    return function_return( statement, SQL_ERROR );
+                    return function_return( SQL_HANDLE_STMT, statement, SQL_ERROR );
                 }
                 else
                 {
@@ -417,9 +440,12 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
             if ( SQL_SUCCEEDED( ret ))
             {
                 /*
-                 * release the implicit descriptors
+                 * release the implicit descriptors, 
+				 * this matches the tests in SQLAllocHandle
                  */
-                if ( statement -> connection -> driver_act_ver == 3 )
+                if (( statement -> connection -> driver_act_ver == 3 &&
+						CHECK_SQLGETSTMTATTR( connection )) ||
+						CHECK_SQLGETSTMTATTRW( connection ))
                 {
                     if ( statement -> implicit_ard )
                         __release_desc( statement -> implicit_ard );
@@ -457,7 +483,7 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         connection -> msg );
             }
 
-            return function_return( connection, ret ); 
+            return function_return( IGNORE_THREAD, connection, ret ); 
         }
         break;
 
@@ -494,6 +520,21 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         descriptor -> msg );
             }
 
+			if ( descriptor -> implicit )
+			{
+				dm_log_write( __FILE__,
+						__LINE__,
+						LOG_INFO,
+						LOG_INFO,
+						"Error: HY017" );
+		
+				__post_internal_error( &descriptor -> error,
+						ERROR_HY017, NULL,
+						connection -> environment -> requested_version );
+		
+				return function_return( SQL_HANDLE_DESC, descriptor, SQL_ERROR );
+			}
+		
             thread_protect( SQL_HANDLE_DESC, descriptor );
 
             if ( !CHECK_SQLFREEHANDLE( connection ))
@@ -508,9 +549,9 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                         ERROR_IM001, NULL,
                         connection -> environment -> requested_version );
 
-                thread_release( SQL_HANDLE_DESC, descriptor );
+            	thread_release( SQL_HANDLE_DESC, descriptor );
 
-                return function_return( descriptor, SQL_ERROR );
+                return function_return( SQL_HANDLE_DESC, descriptor, SQL_ERROR );
             }
             else
             {
@@ -539,7 +580,7 @@ SQLRETURN __SQLFreeHandle( SQLSMALLINT handle_type,
                                UODBC_STATS_TYPE_HDESC, (void *)-1);
 #endif
 
-            return function_return( connection, SQL_SUCCESS ); 
+            return function_return( IGNORE_THREAD, connection, SQL_SUCCESS ); 
         }
         break;
 
