@@ -27,9 +27,42 @@
  *
  **********************************************************************
  *
- * $Id: SQLGetInfo.c,v 1.3 2002/12/05 17:44:31 lurcher Exp $
+ * $Id: SQLGetInfo.c,v 1.12 2008/09/29 14:02:45 lurcher Exp $
  *
  * $Log: SQLGetInfo.c,v $
+ * Revision 1.12  2008/09/29 14:02:45  lurcher
+ * Fix missing dlfcn group option
+ *
+ * Revision 1.11  2007/01/02 10:29:18  lurcher
+ * Fix descriptor leak with unicode only driver
+ *
+ * Revision 1.10  2006/08/31 12:44:52  lurcher
+ * Check in for 2.2.12 release
+ *
+ * Revision 1.9  2006/01/06 18:44:35  lurcher
+ * Couple of unicode fixes
+ *
+ * Revision 1.8  2005/10/06 08:50:58  lurcher
+ * Fix problem with SQLDrivers not returning first entry
+ *
+ * Revision 1.7  2004/11/22 17:02:49  lurcher
+ * Fix unicode/ansi conversion in the SQLGet functions
+ *
+ * Revision 1.6  2003/10/30 18:20:46  lurcher
+ *
+ * Fix broken thread protection
+ * Remove SQLNumResultCols after execute, lease S4/S% to driver
+ * Fix string overrun in SQLDriverConnect
+ * Add initial support for Interix
+ *
+ * Revision 1.5  2003/03/05 09:48:44  lurcher
+ *
+ * Add some 64 bit fixes
+ *
+ * Revision 1.4  2003/02/27 12:19:39  lurcher
+ *
+ * Add the A functions as well as the W
+ *
  * Revision 1.3  2002/12/05 17:44:31  lurcher
  *
  * Display unknown return values in return logging
@@ -132,7 +165,336 @@
 
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: SQLGetInfo.c,v $ $Revision: 1.3 $";
+static char const rcsid[]= "$RCSfile: SQLGetInfo.c,v $ $Revision: 1.12 $";
+
+SQLRETURN SQLGetInfoA( SQLHDBC connection_handle,
+           SQLUSMALLINT info_type,
+           SQLPOINTER info_value,
+           SQLSMALLINT buffer_length,
+           SQLSMALLINT *string_length )
+{
+    return SQLGetInfo( connection_handle,
+                info_type,
+                info_value,
+                buffer_length,
+                string_length );
+}
+
+SQLRETURN __SQLGetInfo( SQLHDBC connection_handle,
+           SQLUSMALLINT info_type,
+           SQLPOINTER info_value,
+           SQLSMALLINT buffer_length,
+           SQLSMALLINT *string_length )
+{
+    DMHDBC connection = (DMHDBC)connection_handle;
+    SQLRETURN ret = SQL_SUCCESS;
+    int type;
+	SQLUSMALLINT sval;
+    char txt[ 30 ], *cptr;
+    SQLPOINTER *ptr;
+    SQLCHAR s1[ 100 + LOG_MESSAGE_LEN ];
+
+    switch ( info_type )
+    {
+      case SQL_DATA_SOURCE_NAME:
+        type = 1;
+        cptr = connection -> dsn;
+        break;
+
+      case SQL_DM_VER:
+        type = 1;
+        sprintf( txt, "%02d.%02d.%04d.%04d",
+                SQL_SPEC_MAJOR, SQL_SPEC_MINOR, 
+                atoi( VERSION ), atoi( VERSION + 2 ));
+        cptr = txt;
+        break;
+
+      case SQL_ODBC_VER:
+        type = 1;
+        sprintf( txt, "%02d.%02d",
+                SQL_SPEC_MAJOR, SQL_SPEC_MINOR );
+        cptr = txt;
+        break;
+
+      case SQL_DRIVER_HDBC:
+        type = 2;
+        ptr = (SQLPOINTER) connection -> driver_dbc;
+        break;
+
+      case SQL_DRIVER_HENV:
+        type = 2;
+        ptr = (SQLPOINTER) connection -> driver_env;
+        break;
+
+      case SQL_DRIVER_HDESC:
+        {
+            DMHDESC hdesc = *((DMHDESC*) info_value); 
+
+            type = 2;
+
+            if ( __validate_desc( hdesc ))
+            {
+                ptr = (SQLPOINTER) hdesc -> driver_desc;
+            }
+            else
+            {
+                dm_log_write( __FILE__, 
+                        __LINE__, 
+                        LOG_INFO, 
+                        LOG_INFO, 
+                        "Error: HY024" );
+
+                __post_internal_error( &connection -> error,
+                        ERROR_HY024, NULL,
+                        connection -> environment -> requested_version );
+
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
+            }
+        }
+        break;
+
+      case SQL_DRIVER_HLIB:
+        type = 2;
+        ptr = connection -> dl_handle;
+        break;
+
+      case SQL_DRIVER_HSTMT:
+        {
+            DMHSTMT hstmt = *((DMHSTMT*) info_value); 
+
+            type = 2;
+
+            if ( __validate_stmt( hstmt ))
+            {
+                ptr = (SQLPOINTER) hstmt -> driver_stmt;
+            }
+            else
+            {
+                dm_log_write( __FILE__, 
+                        __LINE__, 
+                        LOG_INFO, 
+                        LOG_INFO, 
+                        "Error: HY024" );
+
+                __post_internal_error( &connection -> error,
+                        ERROR_HY024, NULL,
+                        connection -> environment -> requested_version );
+
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
+            }
+        }
+        break;
+
+      case SQL_XOPEN_CLI_YEAR:
+        type = 1;
+        cptr = connection -> cli_year;
+        break;
+
+	  case SQL_ATTR_DRIVER_THREADING:
+		type = 3;
+		sval = connection -> threading_level;
+		break;
+
+      default:
+        /*
+         * pass all the others on
+         */
+
+        if ( connection -> unicode_driver )
+        {
+            SQLWCHAR *s1 = NULL;
+
+            if ( !CHECK_SQLGETINFOW( connection ))
+            {
+                dm_log_write( __FILE__, 
+                        __LINE__, 
+                        LOG_INFO, 
+                        LOG_INFO, 
+                        "Error: IM001" );
+
+                __post_internal_error( &connection -> error,
+                        ERROR_IM001, NULL,
+                        connection -> environment -> requested_version );
+
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
+            }
+
+            switch( info_type )
+            {
+              case SQL_ACCESSIBLE_PROCEDURES:
+              case SQL_ACCESSIBLE_TABLES:
+              case SQL_CATALOG_NAME:
+              case SQL_CATALOG_NAME_SEPARATOR:
+              case SQL_CATALOG_TERM:
+              case SQL_COLLATION_SEQ:
+              case SQL_COLUMN_ALIAS:
+              case SQL_DATA_SOURCE_NAME:
+              case SQL_DATA_SOURCE_READ_ONLY:
+              case SQL_DATABASE_NAME:
+              case SQL_DBMS_NAME:
+              case SQL_DBMS_VER:
+              case SQL_DESCRIBE_PARAMETER:
+              case SQL_DRIVER_NAME:
+              case SQL_DRIVER_ODBC_VER:
+              case SQL_DRIVER_VER:
+              case SQL_ODBC_VER:
+              case SQL_EXPRESSIONS_IN_ORDERBY:
+              case SQL_IDENTIFIER_QUOTE_CHAR:
+              case SQL_INTEGRITY:
+              case SQL_KEYWORDS:
+              case SQL_LIKE_ESCAPE_CLAUSE:
+              case SQL_MAX_ROW_SIZE_INCLUDES_LONG:
+              case SQL_MULT_RESULT_SETS:
+              case SQL_MULTIPLE_ACTIVE_TXN:
+              case SQL_NEED_LONG_DATA_LEN:
+              case SQL_ORDER_BY_COLUMNS_IN_SELECT:
+              case SQL_PROCEDURE_TERM:
+              case SQL_PROCEDURES:
+              case SQL_ROW_UPDATES:
+              case SQL_SCHEMA_TERM:
+              case SQL_SEARCH_PATTERN_ESCAPE:
+              case SQL_SERVER_NAME:
+              case SQL_SPECIAL_CHARACTERS:
+              case SQL_TABLE_TERM:
+              case SQL_USER_NAME:
+              case SQL_XOPEN_CLI_YEAR:
+              case SQL_OUTER_JOINS:
+                if ( info_value && buffer_length > 0 )
+                {
+					buffer_length = sizeof( SQLWCHAR ) * ( buffer_length + 1 );
+                    s1 = malloc( buffer_length );
+                }
+                break;
+            }
+
+            ret = SQLGETINFOW( connection,
+                    connection -> driver_dbc,
+                    info_type,
+                    s1 ? s1 : info_value,
+                    buffer_length,
+                    string_length );
+
+            switch( info_type )
+            {
+              case SQL_ACCESSIBLE_PROCEDURES:
+              case SQL_ACCESSIBLE_TABLES:
+              case SQL_CATALOG_NAME:
+              case SQL_CATALOG_NAME_SEPARATOR:
+              case SQL_CATALOG_TERM:
+              case SQL_COLLATION_SEQ:
+              case SQL_COLUMN_ALIAS:
+              case SQL_DATA_SOURCE_NAME:
+              case SQL_DATA_SOURCE_READ_ONLY:
+              case SQL_DATABASE_NAME:
+              case SQL_DBMS_NAME:
+              case SQL_DBMS_VER:
+              case SQL_DESCRIBE_PARAMETER:
+              case SQL_DRIVER_NAME:
+              case SQL_DRIVER_ODBC_VER:
+              case SQL_DRIVER_VER:
+              case SQL_ODBC_VER:
+              case SQL_EXPRESSIONS_IN_ORDERBY:
+              case SQL_IDENTIFIER_QUOTE_CHAR:
+              case SQL_INTEGRITY:
+              case SQL_KEYWORDS:
+              case SQL_LIKE_ESCAPE_CLAUSE:
+              case SQL_MAX_ROW_SIZE_INCLUDES_LONG:
+              case SQL_MULT_RESULT_SETS:
+              case SQL_MULTIPLE_ACTIVE_TXN:
+              case SQL_NEED_LONG_DATA_LEN:
+              case SQL_ORDER_BY_COLUMNS_IN_SELECT:
+              case SQL_PROCEDURE_TERM:
+              case SQL_PROCEDURES:
+              case SQL_ROW_UPDATES:
+              case SQL_SCHEMA_TERM:
+              case SQL_SEARCH_PATTERN_ESCAPE:
+              case SQL_SERVER_NAME:
+              case SQL_SPECIAL_CHARACTERS:
+              case SQL_TABLE_TERM:
+              case SQL_USER_NAME:
+              case SQL_XOPEN_CLI_YEAR:
+              case SQL_OUTER_JOINS:
+                if ( SQL_SUCCEEDED( ret ) && info_value && s1 )
+                {
+                    unicode_to_ansi_copy( info_value, buffer_length, s1, SQL_NTS, connection );
+                }
+				if ( SQL_SUCCEEDED( ret ) && string_length && info_value ) 
+				{
+					*string_length = strlen(info_value);
+				}
+                break;
+            }
+            if ( s1 )
+            {
+                free( s1 );
+            }
+        }
+        else
+        {
+            if ( !CHECK_SQLGETINFO( connection ))
+            {
+                dm_log_write( __FILE__, 
+                        __LINE__, 
+                        LOG_INFO, 
+                        LOG_INFO, 
+                        "Error: IM001" );
+
+                __post_internal_error( &connection -> error,
+                        ERROR_IM001, NULL,
+                        connection -> environment -> requested_version );
+
+                return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
+            }
+
+            ret = SQLGETINFO( connection,
+                    connection -> driver_dbc,
+                    info_type,
+                    info_value,
+                    buffer_length,
+                    string_length );
+        }
+
+        return function_return( SQL_HANDLE_DBC, connection, ret );
+    }
+
+    if ( type == 1 )
+    {
+        if ( string_length )
+            *string_length = strlen( cptr );
+
+        if ( info_value )
+        {
+            if ( buffer_length > strlen( cptr ) + 1 )
+            {
+                strcpy( info_value, cptr );
+            }
+            else
+            {
+                memcpy( info_value, cptr, buffer_length - 1 );
+                ((char*)info_value)[ buffer_length - 1 ] = '\0';
+                ret = SQL_SUCCESS_WITH_INFO;
+            }
+        }
+    }
+    else if ( type == 2 )
+    {
+        if ( info_value )
+            *((void **)info_value) = ptr;
+
+        if ( string_length )
+            *string_length = sizeof( SQLPOINTER );
+    }
+	else if ( type == 3 ) 
+	{
+        if ( info_value )
+            *((SQLUSMALLINT *)info_value) = sval;
+
+        if ( string_length )
+            *string_length = sizeof( SQLUSMALLINT );
+	}
+
+    return function_return( SQL_HANDLE_DBC, connection, ret );
+}
 
 SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
            SQLUSMALLINT info_type,
@@ -143,6 +505,7 @@ SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
     DMHDBC connection = (DMHDBC)connection_handle;
     SQLRETURN ret = SQL_SUCCESS;
     int type;
+	SQLUSMALLINT sval;
     char txt[ 30 ], *cptr;
     SQLPOINTER *ptr;
     SQLCHAR s1[ 100 + LOG_MESSAGE_LEN ];
@@ -201,9 +564,7 @@ SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
                 ERROR_08003, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
     else if ( connection -> state == STATE_C3 )
     {
@@ -217,9 +578,7 @@ SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
                 ERROR_08003, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
     if ( buffer_length < 0 )
@@ -234,315 +593,10 @@ SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
                 ERROR_HY090, NULL,
                 connection -> environment -> requested_version );
 
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, SQL_ERROR );
+        return function_return( SQL_HANDLE_DBC, connection, SQL_ERROR );
     }
 
-    switch ( info_type )
-    {
-      case SQL_DATA_SOURCE_NAME:
-        type = 1;
-        cptr = connection -> dsn;
-        break;
-
-      case SQL_DM_VER:
-        type = 1;
-        sprintf( txt, "%02d.%02d.%04d.%04d",
-                SQL_SPEC_MAJOR, SQL_SPEC_MINOR, 
-                atoi( VERSION ), atoi( VERSION + 2 ));
-        cptr = txt;
-        break;
-
-      case SQL_ODBC_VER:
-        type = 1;
-        sprintf( txt, "%02d.%02d",
-                SQL_SPEC_MAJOR, SQL_SPEC_MINOR );
-        cptr = txt;
-        break;
-
-      case SQL_DRIVER_HDBC:
-        type = 2;
-        ptr = (SQLPOINTER) connection -> driver_dbc;
-        break;
-
-      case SQL_DRIVER_HENV:
-        type = 2;
-        ptr = (SQLPOINTER) connection -> driver_env;
-        break;
-
-      case SQL_DRIVER_HDESC:
-        {
-            DMHDESC hdesc = *((DMHDESC*) info_value); 
-
-            type = 2;
-
-            if ( __validate_desc( hdesc ))
-            {
-                ptr = (SQLPOINTER) hdesc -> driver_desc;
-            }
-            else
-            {
-                dm_log_write( __FILE__, 
-                        __LINE__, 
-                        LOG_INFO, 
-                        LOG_INFO, 
-                        "Error: HY024" );
-
-                __post_internal_error( &connection -> error,
-                        ERROR_HY024, NULL,
-                        connection -> environment -> requested_version );
-
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
-            }
-        }
-        break;
-
-      case SQL_DRIVER_HLIB:
-        type = 2;
-        ptr = connection -> dl_handle;
-        break;
-
-      case SQL_DRIVER_HSTMT:
-        {
-            DMHSTMT hstmt = *((DMHSTMT*) info_value); 
-
-            type = 2;
-
-            if ( __validate_stmt( hstmt ))
-            {
-                ptr = (SQLPOINTER) hstmt -> driver_stmt;
-            }
-            else
-            {
-                dm_log_write( __FILE__, 
-                        __LINE__, 
-                        LOG_INFO, 
-                        LOG_INFO, 
-                        "Error: HY024" );
-
-                __post_internal_error( &connection -> error,
-                        ERROR_HY024, NULL,
-                        connection -> environment -> requested_version );
-
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
-            }
-        }
-        break;
-
-      case SQL_XOPEN_CLI_YEAR:
-        type = 1;
-        cptr = connection -> cli_year;
-        break;
-
-      default:
-        /*
-         * pass all the others on
-         */
-
-        if ( connection -> unicode_driver )
-        {
-            SQLWCHAR *s1 = NULL;
-
-            if ( !CHECK_SQLGETINFOW( connection ))
-            {
-                dm_log_write( __FILE__, 
-                        __LINE__, 
-                        LOG_INFO, 
-                        LOG_INFO, 
-                        "Error: IM001" );
-
-                __post_internal_error( &connection -> error,
-                        ERROR_IM001, NULL,
-                        connection -> environment -> requested_version );
-
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
-            }
-
-            switch( info_type )
-            {
-              case SQL_ACCESSIBLE_PROCEDURES:
-              case SQL_ACCESSIBLE_TABLES:
-              case SQL_CATALOG_NAME:
-              case SQL_CATALOG_NAME_SEPARATOR:
-              case SQL_CATALOG_TERM:
-              case SQL_COLLATION_SEQ:
-              case SQL_COLUMN_ALIAS:
-              case SQL_DATA_SOURCE_NAME:
-              case SQL_DATA_SOURCE_READ_ONLY:
-              case SQL_DATABASE_NAME:
-              case SQL_DBMS_NAME:
-              case SQL_DBMS_VER:
-              case SQL_DESCRIBE_PARAMETER:
-              case SQL_DRIVER_NAME:
-              case SQL_DRIVER_ODBC_VER:
-              case SQL_DRIVER_VER:
-              case SQL_ODBC_VER:
-              case SQL_EXPRESSIONS_IN_ORDERBY:
-              case SQL_IDENTIFIER_QUOTE_CHAR:
-              case SQL_INTEGRITY:
-              case SQL_KEYWORDS:
-              case SQL_LIKE_ESCAPE_CLAUSE:
-              case SQL_MAX_ROW_SIZE_INCLUDES_LONG:
-              case SQL_MULT_RESULT_SETS:
-              case SQL_MULTIPLE_ACTIVE_TXN:
-              case SQL_NEED_LONG_DATA_LEN:
-              case SQL_ORDER_BY_COLUMNS_IN_SELECT:
-              case SQL_PROCEDURE_TERM:
-              case SQL_PROCEDURES:
-              case SQL_ROW_UPDATES:
-              case SQL_SCHEMA_TERM:
-              case SQL_SEARCH_PATTERN_ESCAPE:
-              case SQL_SERVER_NAME:
-              case SQL_SPECIAL_CHARACTERS:
-              case SQL_TABLE_TERM:
-              case SQL_USER_NAME:
-              case SQL_XOPEN_CLI_YEAR:
-              case SQL_OUTER_JOINS:
-                if ( info_value && buffer_length > 0 )
-                {
-                    s1 = malloc( sizeof( SQLWCHAR ) * ( buffer_length + 1 ));
-                }
-                break;
-            }
-
-            ret = SQLGETINFOW( connection,
-                    connection -> driver_dbc,
-                    info_type,
-                    s1 ? s1 : info_value,
-                    buffer_length,
-                    string_length );
-
-            switch( info_type )
-            {
-              case SQL_ACCESSIBLE_PROCEDURES:
-              case SQL_ACCESSIBLE_TABLES:
-              case SQL_CATALOG_NAME:
-              case SQL_CATALOG_NAME_SEPARATOR:
-              case SQL_CATALOG_TERM:
-              case SQL_COLLATION_SEQ:
-              case SQL_COLUMN_ALIAS:
-              case SQL_DATA_SOURCE_NAME:
-              case SQL_DATA_SOURCE_READ_ONLY:
-              case SQL_DATABASE_NAME:
-              case SQL_DBMS_NAME:
-              case SQL_DBMS_VER:
-              case SQL_DESCRIBE_PARAMETER:
-              case SQL_DRIVER_NAME:
-              case SQL_DRIVER_ODBC_VER:
-              case SQL_DRIVER_VER:
-              case SQL_ODBC_VER:
-              case SQL_EXPRESSIONS_IN_ORDERBY:
-              case SQL_IDENTIFIER_QUOTE_CHAR:
-              case SQL_INTEGRITY:
-              case SQL_KEYWORDS:
-              case SQL_LIKE_ESCAPE_CLAUSE:
-              case SQL_MAX_ROW_SIZE_INCLUDES_LONG:
-              case SQL_MULT_RESULT_SETS:
-              case SQL_MULTIPLE_ACTIVE_TXN:
-              case SQL_NEED_LONG_DATA_LEN:
-              case SQL_ORDER_BY_COLUMNS_IN_SELECT:
-              case SQL_PROCEDURE_TERM:
-              case SQL_PROCEDURES:
-              case SQL_ROW_UPDATES:
-              case SQL_SCHEMA_TERM:
-              case SQL_SEARCH_PATTERN_ESCAPE:
-              case SQL_SERVER_NAME:
-              case SQL_SPECIAL_CHARACTERS:
-              case SQL_TABLE_TERM:
-              case SQL_USER_NAME:
-              case SQL_XOPEN_CLI_YEAR:
-              case SQL_OUTER_JOINS:
-                if ( SQL_SUCCEEDED( ret ) && info_value && s1 )
-                {
-                    unicode_to_ansi_copy( info_value, s1, SQL_NTS, connection );
-                }
-                break;
-            }
-
-            if ( s1 )
-            {
-                free( s1 );
-            }
-        }
-        else
-        {
-            if ( !CHECK_SQLGETINFO( connection ))
-            {
-                dm_log_write( __FILE__, 
-                        __LINE__, 
-                        LOG_INFO, 
-                        LOG_INFO, 
-                        "Error: IM001" );
-
-                __post_internal_error( &connection -> error,
-                        ERROR_IM001, NULL,
-                        connection -> environment -> requested_version );
-
-                thread_release( SQL_HANDLE_DBC, connection );
-
-                return function_return( connection, SQL_ERROR );
-            }
-
-            ret = SQLGETINFO( connection,
-                    connection -> driver_dbc,
-                    info_type,
-                    info_value,
-                    buffer_length,
-                    string_length );
-        }
-
-        if ( log_info.log_flag )
-        {
-            sprintf( connection -> msg, 
-                    "\n\t\tExit:[%s]",
-                        __get_return_status( ret, s1 ));
-
-            dm_log_write( __FILE__, 
-                    __LINE__, 
-                    LOG_INFO, 
-                    LOG_INFO, 
-                    connection -> msg );
-        }
-
-        thread_release( SQL_HANDLE_DBC, connection );
-
-        return function_return( connection, ret );
-    }
-
-    if ( type == 1 )
-    {
-        if ( string_length )
-            *string_length = strlen( cptr );
-
-        if ( info_value )
-        {
-            if ( buffer_length > strlen( cptr ) + 1 )
-            {
-                strcpy( info_value, cptr );
-            }
-            else
-            {
-                memcpy( info_value, cptr, buffer_length - 1 );
-                ((char*)info_value)[ buffer_length - 1 ] = '\0';
-                ret = SQL_SUCCESS_WITH_INFO;
-            }
-        }
-    }
-    else if ( type == 2 )
-    {
-        if ( info_value )
-            *((int*)info_value) = (int)ptr;
-
-        if ( string_length )
-            *string_length = sizeof( SQLPOINTER );
-    }
+	ret = __SQLGetInfo(connection_handle, info_type, info_value, buffer_length, string_length);
 
     if ( log_info.log_flag )
     {
@@ -557,7 +611,5 @@ SQLRETURN SQLGetInfo( SQLHDBC connection_handle,
                 connection -> msg );
     }
 
-    thread_release( SQL_HANDLE_DBC, connection );
-
-    return function_return( connection, ret );
+    return function_return( SQL_HANDLE_DBC, connection, ret );
 }
