@@ -27,9 +27,18 @@
  *
  **********************************************************************
  *
- * $Id: SQLSetConnectAttrW.c,v 1.10 2003/10/30 18:20:46 lurcher Exp $
+ * $Id: SQLSetConnectAttrW.c,v 1.13 2008/08/29 08:01:39 lurcher Exp $
  *
  * $Log: SQLSetConnectAttrW.c,v $
+ * Revision 1.13  2008/08/29 08:01:39  lurcher
+ * Alter the way W functions are passed to the driver
+ *
+ * Revision 1.12  2007/02/28 15:37:48  lurcher
+ * deal with drivers that call internal W functions and end up in the driver manager. controlled by the --enable-handlemap configure arg
+ *
+ * Revision 1.11  2006/04/18 10:24:47  lurcher
+ * Add a couple of changes from Mark Vanderwiel
+ *
  * Revision 1.10  2003/10/30 18:20:46  lurcher
  *
  * Fix broken thread protection
@@ -122,6 +131,7 @@ SQLRETURN SQLSetConnectAttrW( SQLHDBC connection_handle,
     DMHDBC connection = (DMHDBC)connection_handle;
     SQLRETURN ret;
     SQLCHAR s1[ 100 + LOG_MESSAGE_LEN ];
+	SQLWCHAR buffer[ 512 ];
 
     /*
      * doesn't require a handle
@@ -196,6 +206,36 @@ SQLRETURN SQLSetConnectAttrW( SQLHDBC connection_handle,
                     LOG_INFO, 
                     "Error: SQL_INVALID_HANDLE" );
 
+#ifdef WITH_HANDLE_REDIRECT
+		{
+			DMHDBC parent_connection;
+
+			parent_connection = find_parent_handle( connection, SQL_HANDLE_DBC );
+
+			if ( parent_connection ) {
+        		dm_log_write( __FILE__, 
+                	__LINE__, 
+                    	LOG_INFO, 
+                    	LOG_INFO, 
+                    	"Info: found parent handle" );
+
+				if ( CHECK_SQLSETCONNECTATTRW( parent_connection ))
+				{
+        			dm_log_write( __FILE__, 
+                		__LINE__, 
+                   		 	LOG_INFO, 
+                   		 	LOG_INFO, 
+                   		 	"Info: calling redirected driver function" );
+
+					return SQLSETCONNECTATTRW( parent_connection, 
+							connection_handle, 
+           					attribute,
+           					value,
+           					string_length );
+				}
+			}
+		}
+#endif
         return SQL_INVALID_HANDLE;
     }
 
@@ -292,7 +332,7 @@ SQLRETURN SQLSetConnectAttrW( SQLHDBC connection_handle,
      * is it something overridden
      */
 
-    value = __attr_override( connection, SQL_HANDLE_DBC, attribute, value, &string_length );
+    value = __attr_override_wide( connection, SQL_HANDLE_DBC, attribute, value, &string_length, buffer );
 
     /*
      * we need to save this even if connected so we can use it for the next connetc
@@ -405,7 +445,8 @@ SQLRETURN SQLSetConnectAttrW( SQLHDBC connection_handle,
     }
     else
     {
-        if ( connection -> unicode_driver )
+        if ( connection -> unicode_driver ||
+			CHECK_SQLSETCONNECTATTRW( connection ))
         {
             if ( !CHECK_SQLSETCONNECTATTRW( connection ))
             {
