@@ -27,9 +27,15 @@
  *
  **********************************************************************
  *
- * $Id: SQLSetConnectOptionW.c,v 1.7 2003/10/30 18:20:46 lurcher Exp $
+ * $Id: SQLSetConnectOptionW.c,v 1.9 2007/02/28 15:37:48 lurcher Exp $
  *
  * $Log: SQLSetConnectOptionW.c,v $
+ * Revision 1.9  2007/02/28 15:37:48  lurcher
+ * deal with drivers that call internal W functions and end up in the driver manager. controlled by the --enable-handlemap configure arg
+ *
+ * Revision 1.8  2006/04/18 10:24:47  lurcher
+ * Add a couple of changes from Mark Vanderwiel
+ *
  * Revision 1.7  2003/10/30 18:20:46  lurcher
  *
  * Fix broken thread protection
@@ -94,6 +100,7 @@ SQLRETURN SQLSetConnectOptionW( SQLHDBC connection_handle,
     DMHDBC connection = (DMHDBC)connection_handle;
     SQLRETURN ret;
     SQLCHAR s1[ 100 + LOG_MESSAGE_LEN ];
+	SQLWCHAR buffer[ 512 ];
 
     /*
      * doesn't require a handle
@@ -137,6 +144,35 @@ SQLRETURN SQLSetConnectOptionW( SQLHDBC connection_handle,
                     LOG_INFO, 
                     "Error: SQL_INVALID_HANDLE" );
 
+#ifdef WITH_HANDLE_REDIRECT
+		{
+			DMHDBC parent_connection;
+
+			parent_connection = find_parent_handle( connection, SQL_HANDLE_DBC );
+
+			if ( parent_connection ) {
+        		dm_log_write( __FILE__, 
+                	__LINE__, 
+                    	LOG_INFO, 
+                    	LOG_INFO, 
+                    	"Info: found parent handle" );
+
+				if ( CHECK_SQLSETCONNECTOPTIONW( parent_connection ))
+				{
+        			dm_log_write( __FILE__, 
+                		__LINE__, 
+                   		 	LOG_INFO, 
+                   		 	LOG_INFO, 
+                   		 	"Info: calling redirected driver function" );
+
+					return SQLSETCONNECTOPTIONW( parent_connection, 
+							connection_handle, 
+							option,
+							value );
+				}
+			}
+		}
+#endif
         return SQL_INVALID_HANDLE;
     }
 
@@ -247,7 +283,7 @@ SQLRETURN SQLSetConnectOptionW( SQLHDBC connection_handle,
      * is it something overridden
      */
 
-    value = (SQLULEN) __attr_override( connection, SQL_HANDLE_DBC, option, (void*) value, NULL );
+    value = (SQLULEN) __attr_override_wide( connection, SQL_HANDLE_DBC, option, (void*) value, NULL, buffer );
 
     if ( option == SQL_ODBC_CURSORS )
     {
