@@ -21,9 +21,22 @@
  *
  **********************************************************************
  *
- * $Id: __attribute.c,v 1.3 2003/01/23 15:33:25 lurcher Exp $
+ * $Id: __attribute.c,v 1.7 2007/07/13 09:01:08 lurcher Exp $
  *
  * $Log: __attribute.c,v $
+ * Revision 1.7  2007/07/13 09:01:08  lurcher
+ * Add isql option to quote field data
+ *
+ * Revision 1.6  2006/04/18 10:24:47  lurcher
+ * Add a couple of changes from Mark Vanderwiel
+ *
+ * Revision 1.5  2004/10/27 08:57:57  lurcher
+ * Remove -module from cur Makefile.am, it seems to stop the lib building on HPUX...
+ *
+ * Revision 1.4  2004/06/21 10:01:12  lurcher
+ *
+ * Fix a couple of 64 bit issues
+ *
  * Revision 1.3  2003/01/23 15:33:25  lurcher
  *
  * Fix problems with using putenv()
@@ -927,7 +940,7 @@ void __release_attr_str( struct attr_struct *attr_str )
 
 static void __set_local_attribute( void *handle, int type, struct attr_set *as )
 {
-    SQLRETURN ret = SQL_ERROR;
+    SQLRETURN ret = SQL_SUCCESS;
 
     if ( type == SQL_HANDLE_ENV )
     {
@@ -1030,14 +1043,14 @@ static void __set_attribute( void *handle, int type, struct attr_set *as )
                     ret = SQLSETCONNECTOPTION( connection,
                             connection -> driver_dbc,
                             as -> attribute,
-                            as -> value );
+                            as -> int_value );
                 }
                 else
                 {
                     ret = SQLSETCONNECTOPTION( connection,
                             connection -> driver_dbc,
                             as -> attribute,
-                            as -> int_value );
+                            as -> value );
                 }
             }
         }
@@ -1050,14 +1063,14 @@ static void __set_attribute( void *handle, int type, struct attr_set *as )
                     ret = SQLSETCONNECTOPTION( connection,
                             connection -> driver_dbc,
                             as -> attribute,
-                            as -> value );
+                            as -> int_value );
                 }
                 else
                 {
                     ret = SQLSETCONNECTOPTION( connection,
                             connection -> driver_dbc,
                             as -> attribute,
-                            as -> int_value );
+                            as -> value );
                 }
             }
         }
@@ -1102,14 +1115,14 @@ static void __set_attribute( void *handle, int type, struct attr_set *as )
                     ret = SQLSETSTMTOPTION( connection,
                             statement -> driver_stmt,
                             as -> attribute,
-                            as -> value );
+                            as -> int_value );
                 }
                 else
                 {
                     ret = SQLSETSTMTOPTION( connection,
                             statement -> driver_stmt,
                             as -> attribute,
-                            as -> int_value );
+                            as -> value );
                 }
             }
         }
@@ -1122,14 +1135,14 @@ static void __set_attribute( void *handle, int type, struct attr_set *as )
                     ret = SQLSETSTMTOPTION( connection,
                             statement -> driver_stmt,
                             as -> attribute,
-                            as -> value );
+                            as -> int_value );
                 }
                 else
                 {
                     ret = SQLSETSTMTOPTION( connection,
                             statement -> driver_stmt,
                             as -> attribute,
-                            as -> int_value );
+                            as -> value );
                 }
             }
         }
@@ -1238,7 +1251,7 @@ void *__attr_override( void *handle, int type, int attribute, void *value, SQLIN
 
         if ( as -> is_int_type )
         {
-            return (void*) as -> int_value;
+            return (void*)(long) as -> int_value;
         }
         else
         {
@@ -1254,3 +1267,74 @@ void *__attr_override( void *handle, int type, int attribute, void *value, SQLIN
         return value;
     }
 }
+
+void *__attr_override_wide( void *handle, int type, int attribute, void *value, SQLINTEGER *string_length, 
+		SQLWCHAR *buffer )
+{
+    struct attr_set *as;
+    char *msg;
+
+    switch( type )
+    {
+      case SQL_HANDLE_DBC:
+        as = ((DMHDBC) handle ) -> dbc_attribute.list;
+        msg = ((DMHDBC) handle ) -> msg;
+        break;
+
+      case SQL_HANDLE_STMT:
+        as = ((DMHSTMT) handle ) -> connection -> stmt_attribute.list;
+        msg = ((DMHSTMT) handle ) -> msg;
+        break;
+
+      default:
+        as = NULL;
+        break;
+    }
+
+    while( as )
+    {
+        if ( as -> override && as -> attribute == attribute )
+        {
+            break;
+        }
+        as = as -> next;
+    }
+
+    if ( as )
+    {
+        if ( log_info.log_flag )
+        {
+            sprintf( msg, "\t\tATTR OVERRIDE [%s=%s]",
+                    as -> keyword + 1, as -> value );
+
+            dm_log_write_diag( msg );
+        }
+
+        if ( as -> is_int_type )
+        {
+            return (void*)(long) as -> int_value;
+        }
+        else
+        {
+            if ( string_length )
+            {
+                *string_length = strlen( as -> value ) * sizeof( SQLWCHAR );
+            }
+			switch( type ) 
+			{
+      			case SQL_HANDLE_DBC:
+					ansi_to_unicode_copy( buffer, as->value, SQL_NTS, (DMHDBC) handle );
+					break;
+
+      			case SQL_HANDLE_STMT:
+					ansi_to_unicode_copy( buffer, as->value, SQL_NTS, ((DMHSTMT) handle ) -> connection );
+					break;
+			}
+            return buffer;
+        }
+    }
+    else
+    {
+        return value;
+    }
+}
