@@ -27,9 +27,15 @@
  *
  **********************************************************************
  *
- * $Id: __stats.c,v 1.1.1.1 2001/10/17 16:40:09 lurcher Exp $
+ * $Id: __stats.c,v 1.2 2004/05/07 09:53:13 lurcher Exp $
  *
  * $Log: __stats.c,v $
+ * Revision 1.2  2004/05/07 09:53:13  lurcher
+ *
+ *
+ * Fix potential problrm in stats if creating a semaphore fails
+ * Alter state after SQLParamData from S4 to S5
+ *
  * Revision 1.1.1.1  2001/10/17 16:40:09  lurcher
  *
  * First upload to SourceForge
@@ -105,7 +111,7 @@
 #include <uodbc_stats.h>
 #include "drivermanager.h"
 
-static char const rcsid[]= "$RCSfile: __stats.c,v $ $Revision: 1.1.1.1 $";
+static char const rcsid[]= "$RCSfile: __stats.c,v $ $Revision: 1.2 $";
 
 #ifdef COLLECT_STATS
 #ifdef HAVE_LIBPTHREAD
@@ -256,14 +262,15 @@ int uodbc_open_stats(
     else if (shm_created)
     {
         unsigned int    i;
+        int lk;
         
-        acquire_sem_lock(lh.sem_id);
+        lk = acquire_sem_lock(lh.sem_id);
         memset(lh.stats, '\0', sizeof(uodbc_stats_t));
         for (i = 0; i < (sizeof(lh.stats->perpid) / sizeof(lh.stats->perpid[0])); i++)
         {
             lh.stats->perpid[i].pid = (pid_t)0;
         }
-        release_sem_lock(lh.sem_id);
+        if (lk == 0) release_sem_lock(lh.sem_id);
     }
     if ((h = calloc(1, sizeof(uodbc_stats_handle_t))) == NULL) return -1;
     memcpy(h, &lh, sizeof(uodbc_stats_handle_t));
@@ -273,7 +280,9 @@ int uodbc_open_stats(
      */
     if (mode & UODBC_STATS_WRITE)
     {
-        acquire_sem_lock(lh.sem_id);
+        int lk;
+        
+        lk = acquire_sem_lock(lh.sem_id);
         for (i = 0;
              i < (sizeof(h->stats->perpid) / sizeof(h->stats->perpid[0]));
              i++)
@@ -288,7 +297,7 @@ int uodbc_open_stats(
                 break;
             }
         }
-        release_sem_lock(lh.sem_id);        
+        if (lk == 0) release_sem_lock(lh.sem_id);
     }
     
     *(uodbc_stats_handle_t **)rh = h;
@@ -359,7 +368,8 @@ int uodbc_update_stats(void *h,
     unsigned long               type;
     unsigned int                i;
     uodbc_stats_handle_t        *sh;
-
+    int lk;
+    
     sh = (uodbc_stats_handle_t *)h;
     if (!sh)
     {
@@ -377,7 +387,7 @@ int uodbc_update_stats(void *h,
         return -1;
     }
 
-    acquire_sem_lock(sh->sem_id);
+    lk = acquire_sem_lock(sh->sem_id);
     /*
      *  Find this PID in array
      */
@@ -395,7 +405,7 @@ int uodbc_update_stats(void *h,
         /*
          *  array full - process not entered.
          */
-        release_sem_lock(sh->sem_id);
+        if (lk == 0) release_sem_lock(sh->sem_id);
         return 0;
     }
 
@@ -427,7 +437,7 @@ int uodbc_update_stats(void *h,
           break;
       }
     }
-    release_sem_lock(sh->sem_id);
+    if (lk == 0) release_sem_lock(sh->sem_id);
     
     return 0;
 }
