@@ -675,6 +675,7 @@ int lobj_fd, retval;
 #ifdef HAVE_LOCALTIME_R
 struct tm tp;
 #endif
+size_t ollen;
 
 
 	if ( ! old_statement) {
@@ -700,7 +701,8 @@ struct tm tp;
 
     param_number = -1;
 
-    for (opos = 0; opos < strlen(old_statement); opos++) {
+	ollen = strlen(old_statement);
+    for (opos = 0; opos < ollen; opos++) {
 
 		/*//	Squeeze carriage-returns/linfeed pairs to linefeed only */
 		if (old_statement[opos] == '\r' && opos+1<strlen(old_statement) && old_statement[opos+1] == '\n') {
@@ -859,7 +861,11 @@ struct tm tp;
 
 		case SQL_C_SLONG:
 		case SQL_C_LONG:
+#if (SIZEOF_LONG == 4)
 			sprintf(param_string, "%ld",
+#else
+			sprintf(param_string, "%d",
+#endif
 				*((SDWORD *) buffer));
 			break;
 
@@ -876,7 +882,11 @@ struct tm tp;
 			break;
 
 		case SQL_C_ULONG:
+#if (SIZEOF_LONG == 4)
 			sprintf(param_string, "%lu",
+#else
+			sprintf(param_string, "%u",
+#endif
 				*((UDWORD *) buffer));
 			break;
 
@@ -1073,7 +1083,7 @@ struct tm tp;
                 }
 
 				/*	store the oid */
-				lobj_oid = lo_creat(stmt->hdbc, INV_READ | INV_WRITE);
+				lobj_oid = odbc_lo_creat(stmt->hdbc, INV_READ | INV_WRITE);
 				if (lobj_oid == 0) {
 					stmt->errornumber = STMT_EXEC_ERROR;
 					stmt->errormsg = "Couldnt create (in-line) large object.";
@@ -1082,7 +1092,7 @@ struct tm tp;
 				}
 
 				/*	store the fd */
-				lobj_fd = lo_open(stmt->hdbc, lobj_oid, INV_WRITE);
+				lobj_fd = odbc_lo_open(stmt->hdbc, lobj_oid, INV_WRITE);
 				if ( lobj_fd < 0) {
 					stmt->errornumber = STMT_EXEC_ERROR;
 					stmt->errormsg = "Couldnt open (in-line) large object for writing.";
@@ -1090,9 +1100,9 @@ struct tm tp;
 					return SQL_ERROR;
 				}
 
-				retval = lo_write(stmt->hdbc, lobj_fd, buffer, used);
+				retval = odbc_lo_write(stmt->hdbc, lobj_fd, buffer, used);
 
-				lo_close(stmt->hdbc, lobj_fd);
+				odbc_lo_close(stmt->hdbc, lobj_fd);
  
                                 /* commit transaction if needed */
                                 if (!globals.use_declarefetch && CC_is_in_autocommit(stmt->hdbc)) {
@@ -1218,9 +1228,9 @@ char *mapFunc;
 char *
 convert_money(char *s)
 {
-size_t i = 0, out = 0;
+size_t i = 0, out = 0, slen=strlen(s);
 
-	for (i = 0; i < strlen(s); i++) {
+	for (i = 0; i < slen; i++) {
 		if (s[i] == '$' || s[i] == ',' || s[i] == ')')
 			; /*// skip these characters */
 		else if (s[i] == '(')
@@ -1392,11 +1402,10 @@ int i, y=0, val;
 int
 convert_from_pgbinary(unsigned char *value, unsigned char *rgbValue, int cbValueMax)
 {
-size_t i;
+size_t i, valen=strlen((char*)value);
 int o=0;
-
 	
-    for (i = 0; i < strlen((char*)value) && o < cbValueMax; ) 
+    for (i = 0; i < valen && o < cbValueMax; ) 
     {
 		if (value[i] == '\\') 
         {
@@ -1464,8 +1473,9 @@ void
 encode(char *in, char *out)
 {
 unsigned int i, o = 0;
+size_t inlen=strlen(in);
 
-	for (i = 0; i < strlen(in); i++) {
+	for (i = 0; i < inlen; i++) {
 		if ( in[i] == '+') {
 			sprintf(&out[o], "%%2B");
 			o += 3;
@@ -1488,8 +1498,9 @@ void
 decode(char *in, char *out)
 {
 unsigned int i, o = 0;
+size_t inlen=strlen(in);
 
-	for (i = 0; i < strlen(in); i++) {
+	for (i = 0; i < inlen; i++) {
 		if (in[i] == '+')
 			out[o++] = ' ';
 		else if (in[i] == '%') {
@@ -1563,7 +1574,7 @@ BindInfoClass *bindInfo = NULL;
                 }
  
 		oid = atoi(value);
-		stmt->lobj_fd = lo_open(stmt->hdbc, oid, INV_READ);
+		stmt->lobj_fd = odbc_lo_open(stmt->hdbc, oid, INV_READ);
 		if (stmt->lobj_fd < 0) {
 			stmt->errornumber = STMT_EXEC_ERROR;
 			stmt->errormsg = "Couldnt open large object for reading.";
@@ -1571,15 +1582,15 @@ BindInfoClass *bindInfo = NULL;
 		}
 
 		/*	Get the size */
-		retval = lo_lseek(stmt->hdbc, stmt->lobj_fd, 0L, SEEK_END);
+		retval = odbc_lo_lseek(stmt->hdbc, stmt->lobj_fd, 0L, SEEK_END);
 		if (retval >= 0) {
 
-			left = lo_tell(stmt->hdbc, stmt->lobj_fd);
+			left = odbc_lo_tell(stmt->hdbc, stmt->lobj_fd);
 			if (bindInfo)
 				bindInfo->data_left = left;
 
 			/*	return to beginning */
-			lo_lseek(stmt->hdbc, stmt->lobj_fd, 0L, SEEK_SET);
+			odbc_lo_lseek(stmt->hdbc, stmt->lobj_fd, 0L, SEEK_SET);
 		}
 	}
 
@@ -1593,9 +1604,9 @@ BindInfoClass *bindInfo = NULL;
 		return COPY_GENERAL_ERROR;
 	}
 
-	retval = lo_read(stmt->hdbc, stmt->lobj_fd, (char *) rgbValue, cbValueMax);
+	retval = odbc_lo_read(stmt->hdbc, stmt->lobj_fd, (char *) rgbValue, cbValueMax);
 	if (retval < 0) {
-		lo_close(stmt->hdbc, stmt->lobj_fd);
+		odbc_lo_close(stmt->hdbc, stmt->lobj_fd);
  
                 /* commit transaction if needed */
                 if (!globals.use_declarefetch && CC_is_in_autocommit(stmt->hdbc))
@@ -1641,7 +1652,7 @@ BindInfoClass *bindInfo = NULL;
 
 
 	if (! bindInfo || bindInfo->data_left == 0) {
-		lo_close(stmt->hdbc, stmt->lobj_fd);
+		odbc_lo_close(stmt->hdbc, stmt->lobj_fd);
 
                 /* commit transaction if needed */
                 if (!globals.use_declarefetch && CC_is_in_autocommit(stmt->hdbc))
