@@ -563,7 +563,7 @@ int i, retval;
 
 	/* close the large object */
 	if ( stmt->lobj_fd >= 0) {
-		lo_close(stmt->hdbc, stmt->lobj_fd);
+		odbc_lo_close(stmt->hdbc, stmt->lobj_fd);
  
                 /* commit transaction if needed */
                 if (!globals.use_declarefetch && CC_is_in_autocommit(stmt->hdbc))
@@ -703,7 +703,7 @@ char *buffer;
                         }
  
 			/*	store the oid */
-			current_param->lobj_oid = lo_creat(stmt->hdbc, INV_READ | INV_WRITE);
+			current_param->lobj_oid = odbc_lo_creat(stmt->hdbc, INV_READ | INV_WRITE);
 			if (current_param->lobj_oid == 0) {
 				stmt->errornumber = STMT_EXEC_ERROR;
 				stmt->errormsg = "Couldnt create large object.";
@@ -716,7 +716,7 @@ char *buffer;
 			current_param->EXEC_buffer = (char *) &current_param->lobj_oid;
 
 			/*	store the fd */
-			stmt->lobj_fd = lo_open(stmt->hdbc, current_param->lobj_oid, INV_WRITE);
+			stmt->lobj_fd = odbc_lo_open(stmt->hdbc, current_param->lobj_oid, INV_WRITE);
 			if ( stmt->lobj_fd < 0) {
 				stmt->errornumber = STMT_EXEC_ERROR;
 				stmt->errormsg = "Couldnt open large object for writing.";
@@ -724,8 +724,8 @@ char *buffer;
 				return SQL_ERROR;
 			}
 
-			retval = lo_write(stmt->hdbc, stmt->lobj_fd, rgbValue, cbValue);
-			mylog("lo_write: cbValue=%d, wrote %d bytes\n", cbValue, retval);
+			retval = odbc_lo_write(stmt->hdbc, stmt->lobj_fd, rgbValue, cbValue);
+			mylog("odbc_lo_write: cbValue=%d, wrote %d bytes\n", cbValue, retval);
 
 		}
 		else {	/* for handling text fields and small binaries */
@@ -760,8 +760,8 @@ char *buffer;
 		if (current_param->SQLType == SQL_LONGVARBINARY) {
 
 			/* the large object fd is in EXEC_buffer */
-			retval = lo_write(stmt->hdbc, stmt->lobj_fd, rgbValue, cbValue);
-			mylog("lo_write(2): cbValue = %d, wrote %d bytes\n", cbValue, retval);
+			retval = odbc_lo_write(stmt->hdbc, stmt->lobj_fd, rgbValue, cbValue);
+			mylog("odbc_lo_write(2): cbValue = %d, wrote %d bytes\n", cbValue, retval);
 
 			*current_param->EXEC_used += cbValue;
 
