@@ -27,13 +27,13 @@ typedef struct bound_column
 {
     struct bound_column     *next;
     int                     column_number;
-    SQLINTEGER              len_ind;
+    SQLLEN                  len_ind;
     SQLPOINTER              local_buffer;   /* buffer that the CL binds in */
                                             /* the driver (malloc'd) */
     SQLPOINTER              bound_buffer;   /* buffer that the app binds */
     SQLINTEGER              bound_type;     /* data type of binding */
-    SQLINTEGER              bound_length;   /* length of binding */
-    SQLINTEGER              *bound_ind;     /* ind ptr bound */
+    SQLLEN              	bound_length;   /* length of binding */
+    SQLLEN              	*bound_ind;     /* ind ptr bound */
     int                     rs_buffer_offset;
     int                     rs_ind_offset;  /* offset onto the current rowset */
                                             /* buffer */
@@ -43,7 +43,7 @@ typedef struct cl_connection
 {
     struct driver_func *functions;      /* entry points, from the original */
                                         /* driver */
-    SQLHANDLE           driver_dbc;     /* HDBC of the driver */
+    DRV_SQLHANDLE       driver_dbc;     /* HDBC of the driver */
     DMHDBC              dm_connection;  /* driver manager connection str */ 
     DMHSTMT             cl_handle;      /* dummy to make the macro valid */
     SQLUSMALLINT        active_statement_allowed;
@@ -60,9 +60,10 @@ typedef struct cl_connection
 
 typedef struct cl_statement
 {
-    SQLHANDLE           driver_stmt;    /* driver sattement handle */
+    DRV_SQLHANDLE       driver_stmt;    /* driver statement handle */
     CLHDBC              cl_connection;  /* parent cursor lib connection */
     DMHSTMT             dm_statement;   /* Driver manager statement */
+    DMHSTMT             fetch_statement;   /* Driver manager statement */
     SQLUINTEGER         cursor_type;    /* statment attr's */
     SQLUINTEGER         concurrency;
     SQLPOINTER          *fetch_bookmark_ptr;
@@ -71,6 +72,7 @@ typedef struct cl_statement
     SQLPOINTER          row_bind_offset_ptr;
     SQLUINTEGER         row_bind_type;
     SQLUINTEGER         rowset_array_size;
+    SQLUINTEGER         rowset_size;
     SQLUINTEGER         simulate_cursor;
     SQLUINTEGER         use_bookmarks;
     SQLUINTEGER         *rows_fetched_ptr;
@@ -81,11 +83,12 @@ typedef struct cl_statement
     char                *sql_text;      /* text of current statement */
     char                **column_names; /* names of each column */
     SQLSMALLINT         *data_type;
-    SQLINTEGER          *column_size;
+    SQLLEN              *column_size;
     SQLSMALLINT         *decimal_digits;
     int                 driver_stmt_closed;
     int                 not_from_select;
     int                 read_only;
+	int					fetch_done;
     /*
      * rowset info
      */
@@ -105,74 +108,74 @@ typedef struct cl_statement
  * cursor lib function defs
  */
 
-SQLRETURN CLAllocHandle( SQLSMALLINT handle_type,
+SQLRETURN SQL_API CLAllocHandle( SQLSMALLINT handle_type,
            SQLHANDLE input_handle,
            SQLHANDLE *output_handle,
            SQLHANDLE dm_handle );
 
-SQLRETURN CLAllocHandleStd(
+SQLRETURN SQL_API CLAllocHandleStd(
            SQLSMALLINT        handle_type,
            SQLHANDLE          input_handle,
            SQLHANDLE          *output_handle,
            SQLHANDLE          dm_handle );
 
-SQLRETURN CLAllocStmt( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLAllocStmt( SQLHDBC connection_handle,
            SQLHSTMT *statement_handle,
            SQLHANDLE dm_handle );
 
-SQLRETURN CLBindCol( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLBindCol( SQLHSTMT statement_handle,
 		   SQLUSMALLINT column_number,
            SQLSMALLINT target_type,
 		   SQLPOINTER target_value,
-           SQLINTEGER buffer_length,
-	   	   SQLINTEGER *strlen_or_ind );
+           SQLLEN buffer_length,
+	   	   SQLLEN *strlen_or_ind );
 
-SQLRETURN CLBindParam( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLBindParam( SQLHSTMT statement_handle,
            SQLUSMALLINT parameter_number,
            SQLSMALLINT value_type,
            SQLSMALLINT parameter_type,
-           SQLUINTEGER length_precision,
+           SQLULEN length_precision,
            SQLSMALLINT parameter_scale,
            SQLPOINTER parameter_value,
-           SQLINTEGER *strlen_or_ind );
+           SQLLEN *strlen_or_ind );
 
-SQLRETURN CLBindParameter(
+SQLRETURN SQL_API CLBindParameter(
            SQLHSTMT           statement_handle,
            SQLUSMALLINT       ipar,
            SQLSMALLINT        f_param_type,
            SQLSMALLINT        f_c_type,
            SQLSMALLINT        f_sql_type,
-           SQLUINTEGER        cb_col_def,
+           SQLULEN        	  cb_col_def,
            SQLSMALLINT        ib_scale,
            SQLPOINTER         rgb_value,
-           SQLINTEGER         cb_value_max,
-           SQLINTEGER         *pcb_value );
+           SQLLEN             cb_value_max,
+           SQLLEN             *pcb_value );
        
-SQLRETURN CLBulkOperations(
+SQLRETURN SQL_API CLBulkOperations(
            SQLHSTMT        statement_handle,
            SQLSMALLINT     operation );
 
-SQLRETURN CLCancel( SQLHSTMT statement_handle );
+SQLRETURN SQL_API CLCancel( SQLHSTMT statement_handle );
 
-SQLRETURN CLCloseCursor( SQLHSTMT statement_handle );
+SQLRETURN SQL_API CLCloseCursor( SQLHSTMT statement_handle );
 
-SQLRETURN CLColAttribute ( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLColAttribute ( SQLHSTMT statement_handle,
            SQLUSMALLINT column_number,
            SQLUSMALLINT field_identifier,
            SQLPOINTER character_attribute,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *string_length,
-           SQLPOINTER numeric_attribute );
+           SQLLEN *numeric_attribute );
 
-SQLRETURN CLColAttributes( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLColAttributes( SQLHSTMT statement_handle,
            SQLUSMALLINT column_number,
            SQLUSMALLINT field_identifier,
            SQLPOINTER   character_attribute,
            SQLSMALLINT  buffer_length,
            SQLSMALLINT  *string_length,
-           SQLINTEGER   *numeric_attribute );
+           SQLLEN       *numeric_attribute );
 
-SQLRETURN CLColumnPrivileges(
+SQLRETURN SQL_API CLColumnPrivileges(
            SQLHSTMT            statement_handle,
            SQLCHAR             *catalog_name,
            SQLSMALLINT         name_length1,
@@ -183,7 +186,7 @@ SQLRETURN CLColumnPrivileges(
            SQLCHAR             *column_name,
            SQLSMALLINT         name_length4 );
 
-SQLRETURN CLColumns( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLColumns( SQLHSTMT statement_handle,
            SQLCHAR *catalog_name,
            SQLSMALLINT name_length1,
            SQLCHAR *schema_name,
@@ -193,34 +196,34 @@ SQLRETURN CLColumns( SQLHSTMT statement_handle,
            SQLCHAR *column_name,
            SQLSMALLINT name_length4 );
 
-SQLRETURN CLCopyDesc( SQLHDESC source_desc_handle,
+SQLRETURN SQL_API CLCopyDesc( SQLHDESC source_desc_handle,
            SQLHDESC target_desc_handle );
 
-SQLRETURN CLDescribeCol( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLDescribeCol( SQLHSTMT statement_handle,
            SQLUSMALLINT column_number,
            SQLCHAR *column_name,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *name_length,
            SQLSMALLINT *data_type,
-           SQLUINTEGER *column_size,
+           SQLULEN     *column_size,
            SQLSMALLINT *decimal_digits,
            SQLSMALLINT *nullable );
 
-SQLRETURN CLDescribeParam(
+SQLRETURN SQL_API CLDescribeParam(
            SQLHSTMT           statement_handle,
            SQLUSMALLINT       ipar,
            SQLSMALLINT        *pf_sql_type,
-           SQLUINTEGER        *pcb_param_def,
+           SQLULEN            *pcb_param_def,
            SQLSMALLINT        *pib_scale,
            SQLSMALLINT        *pf_nullable );
 
-SQLRETURN CLDisconnect( SQLHDBC connection_handle );
+SQLRETURN SQL_API CLDisconnect( SQLHDBC connection_handle );
 
-SQLRETURN CLEndTran( SQLSMALLINT handle_type,
+SQLRETURN SQL_API CLEndTran( SQLSMALLINT handle_type,
         SQLHANDLE handle,
         SQLSMALLINT completion_type );
 
-SQLRETURN CLError( SQLHENV environment_handle,
+SQLRETURN SQL_API CLError( SQLHENV environment_handle,
            SQLHDBC connection_handle,
            SQLHSTMT statement_handle,
            SQLCHAR *sqlstate,
@@ -229,26 +232,26 @@ SQLRETURN CLError( SQLHENV environment_handle,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *text_length );
 
-SQLRETURN CLExecDirect( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLExecDirect( SQLHSTMT statement_handle,
            SQLCHAR *statement_text,
            SQLINTEGER text_length );
 
-SQLRETURN CLExecute( SQLHSTMT statement_handle );
+SQLRETURN SQL_API CLExecute( SQLHSTMT statement_handle );
 
-SQLRETURN CLExtendedFetch(
+SQLRETURN SQL_API CLExtendedFetch(
            SQLHSTMT           statement_handle,
            SQLUSMALLINT       f_fetch_type,
-           SQLINTEGER         irow,
-           SQLUINTEGER        *pcrow,
+           SQLLEN             irow,
+           SQLULEN            *pcrow,
            SQLUSMALLINT       *rgf_row_status );
 
-SQLRETURN CLFetch( SQLHSTMT statement_handle );
+SQLRETURN SQL_API CLFetch( SQLHSTMT statement_handle );
 
-SQLRETURN CLFetchScroll( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLFetchScroll( SQLHSTMT statement_handle,
            SQLSMALLINT fetch_orientation,
-           SQLINTEGER fetch_offset );
+           SQLLEN fetch_offset );
 
-SQLRETURN CLForeignKeys(
+SQLRETURN SQL_API CLForeignKeys(
            SQLHSTMT           statement_handle,
            SQLCHAR            *szpk_catalog_name,
            SQLSMALLINT        cbpk_catalog_name,
@@ -263,42 +266,42 @@ SQLRETURN CLForeignKeys(
            SQLCHAR            *szfk_table_name,
            SQLSMALLINT        cbfk_table_name );
 
-SQLRETURN CLFreeHandle( SQLSMALLINT handle_type,
+SQLRETURN SQL_API CLFreeHandle( SQLSMALLINT handle_type,
            SQLHANDLE handle );
 
-SQLRETURN CLFreeStmt( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLFreeStmt( SQLHSTMT statement_handle,
            SQLUSMALLINT option );
 
-SQLRETURN CLGetConnectOption( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLGetConnectOption( SQLHDBC connection_handle,
            SQLUSMALLINT option,
            SQLPOINTER value );
 
-SQLRETURN CLGetConnectAttr( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLGetConnectAttr( SQLHDBC connection_handle,
            SQLINTEGER attribute,
            SQLPOINTER value,
            SQLINTEGER buffer_length,
            SQLINTEGER *string_length );
 
-SQLRETURN CLGetCursorName( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLGetCursorName( SQLHSTMT statement_handle,
            SQLCHAR *cursor_name,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *name_length );
 
-SQLRETURN CLGetData( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLGetData( SQLHSTMT statement_handle,
            SQLUSMALLINT column_number,
            SQLSMALLINT target_type,
            SQLPOINTER target_value,
-           SQLINTEGER buffer_length,
-           SQLINTEGER *strlen_or_ind );
+           SQLLEN buffer_length,
+           SQLLEN *strlen_or_ind );
 
-SQLRETURN CLGetDescField( SQLHDESC descriptor_handle,
+SQLRETURN SQL_API CLGetDescField( SQLHDESC descriptor_handle,
            SQLSMALLINT rec_number, 
            SQLSMALLINT field_identifier,
            SQLPOINTER value, 
            SQLINTEGER buffer_length,
            SQLINTEGER *string_length );
 
-SQLRETURN CLGetDescRec( SQLHDESC descriptor_handle,
+SQLRETURN SQL_API CLGetDescRec( SQLHDESC descriptor_handle,
            SQLSMALLINT rec_number, 
            SQLCHAR *name,
            SQLSMALLINT buffer_length, 
@@ -310,7 +313,7 @@ SQLRETURN CLGetDescRec( SQLHDESC descriptor_handle,
            SQLSMALLINT *scale, 
            SQLSMALLINT *nullable );
 
-SQLRETURN CLGetDiagField( SQLSMALLINT handle_type,
+SQLRETURN SQL_API CLGetDiagField( SQLSMALLINT handle_type,
            SQLHANDLE handle,
            SQLSMALLINT rec_number,
            SQLSMALLINT diag_identifier,
@@ -318,7 +321,7 @@ SQLRETURN CLGetDiagField( SQLSMALLINT handle_type,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *string_length_ptr );
 
-SQLRETURN CLGetDiagRec( SQLSMALLINT handle_type,
+SQLRETURN SQL_API CLGetDiagRec( SQLSMALLINT handle_type,
            SQLHANDLE   handle,
            SQLSMALLINT rec_number,
            SQLCHAR     *sqlstate,
@@ -327,28 +330,28 @@ SQLRETURN CLGetDiagRec( SQLSMALLINT handle_type,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *text_length_ptr );
 
-SQLRETURN CLGetInfo( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLGetInfo( SQLHDBC connection_handle,
            SQLUSMALLINT info_type,
            SQLPOINTER info_value,
            SQLSMALLINT buffer_length,
            SQLSMALLINT *string_length );
 
-SQLRETURN CLGetStmtAttr( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLGetStmtAttr( SQLHSTMT statement_handle,
            SQLINTEGER attribute,
            SQLPOINTER value,
            SQLINTEGER buffer_length,
            SQLINTEGER *string_length );
 
-SQLRETURN CLGetStmtOption( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLGetStmtOption( SQLHSTMT statement_handle,
            SQLUSMALLINT option,
            SQLPOINTER value );
 
-SQLRETURN CLGetTypeInfo( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLGetTypeInfo( SQLHSTMT statement_handle,
            SQLSMALLINT data_type );
 
-SQLRETURN CLMoreResults( SQLHSTMT statement_handle );
+SQLRETURN SQL_API CLMoreResults( SQLHSTMT statement_handle );
 
-SQLRETURN CLNativeSql(
+SQLRETURN SQL_API CLNativeSql(
            SQLHDBC            hdbc,
            SQLCHAR            *sz_sql_str_in,
            SQLINTEGER         cb_sql_str_in,
@@ -356,26 +359,26 @@ SQLRETURN CLNativeSql(
            SQLINTEGER         cb_sql_str_max,
            SQLINTEGER         *pcb_sql_str );
 
-SQLRETURN CLNumParams(
+SQLRETURN SQL_API CLNumParams(
            SQLHSTMT           statement_handle,
            SQLSMALLINT        *pcpar );
 
-SQLRETURN CLNumResultCols( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLNumResultCols( SQLHSTMT statement_handle,
            SQLSMALLINT *column_count );
 
-SQLRETURN CLParamData( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLParamData( SQLHSTMT statement_handle,
            SQLPOINTER *value );
 
-SQLRETURN CLParamOptions(
+SQLRETURN SQL_API CLParamOptions(
            SQLHSTMT           statement_handle,
-           SQLUINTEGER        crow,
-           SQLUINTEGER        *pirow );
+           SQLULEN        	  crow,
+           SQLULEN        	  *pirow );
 
-SQLRETURN CLPrepare( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLPrepare( SQLHSTMT statement_handle,
            SQLCHAR *statement_text,
            SQLINTEGER text_length );
 
-SQLRETURN CLPrimaryKeys(
+SQLRETURN SQL_API CLPrimaryKeys(
            SQLHSTMT           statement_handle,
            SQLCHAR            *sz_catalog_name,
            SQLSMALLINT        cb_catalog_name,
@@ -384,7 +387,7 @@ SQLRETURN CLPrimaryKeys(
            SQLCHAR            *sz_table_name,
            SQLSMALLINT        cb_table_name );
 
-SQLRETURN CLProcedureColumns(
+SQLRETURN SQL_API CLProcedureColumns(
            SQLHSTMT           statement_handle,
            SQLCHAR            *sz_catalog_name,
            SQLSMALLINT        cb_catalog_name,
@@ -395,7 +398,7 @@ SQLRETURN CLProcedureColumns(
            SQLCHAR            *sz_column_name,
            SQLSMALLINT        cb_column_name );
 
-SQLRETURN CLProcedures(
+SQLRETURN SQL_API CLProcedures(
            SQLHSTMT           statement_handle,
            SQLCHAR            *sz_catalog_name,
            SQLSMALLINT        cb_catalog_name,
@@ -404,74 +407,74 @@ SQLRETURN CLProcedures(
            SQLCHAR            *sz_proc_name,
            SQLSMALLINT        cb_proc_name );
 
-SQLRETURN CLPutData( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLPutData( SQLHSTMT statement_handle,
            SQLPOINTER data,
            SQLINTEGER strlen_or_ind );
 
-SQLRETURN CLRowCount( SQLHSTMT statement_handle,
-           SQLINTEGER *rowcount );
+SQLRETURN SQL_API CLRowCount( SQLHSTMT statement_handle,
+           SQLLEN *rowcount );
 
-SQLRETURN CLSetConnectAttr( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLSetConnectAttr( SQLHDBC connection_handle,
            SQLINTEGER attribute,
            SQLPOINTER value,
            SQLINTEGER string_length );
 
-SQLRETURN CLSetConnectOption( SQLHDBC connection_handle,
+SQLRETURN SQL_API CLSetConnectOption( SQLHDBC connection_handle,
            SQLUSMALLINT option,
-           SQLUINTEGER value );
+           SQLULEN value );
 
-SQLRETURN CLSetCursorName( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLSetCursorName( SQLHSTMT statement_handle,
            SQLCHAR *cursor_name,
            SQLSMALLINT name_length );
 
-SQLRETURN CLSetDescField( SQLHDESC descriptor_handle,
+SQLRETURN SQL_API CLSetDescField( SQLHDESC descriptor_handle,
            SQLSMALLINT rec_number, 
            SQLSMALLINT field_identifier,
            SQLPOINTER value, 
            SQLINTEGER buffer_length );
 
-SQLRETURN CLSetDescRec( SQLHDESC descriptor_handle,
+SQLRETURN SQL_API CLSetDescRec( SQLHDESC descriptor_handle,
            SQLSMALLINT rec_number, 
            SQLSMALLINT type,
            SQLSMALLINT subtype, 
-           SQLINTEGER length,
+           SQLLEN length,
            SQLSMALLINT precision, 
            SQLSMALLINT scale,
            SQLPOINTER data, 
-           SQLINTEGER *string_length,
-           SQLINTEGER *indicator );
+           SQLLEN *string_length,
+           SQLLEN *indicator );
 
-SQLRETURN CLSetParam( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLSetParam( SQLHSTMT statement_handle,
            SQLUSMALLINT parameter_number,
            SQLSMALLINT value_type,
            SQLSMALLINT parameter_type,
-           SQLUINTEGER length_precision,
+           SQLULEN length_precision,
            SQLSMALLINT parameter_scale,
            SQLPOINTER parameter_value,
-           SQLINTEGER *strlen_or_ind );
+           SQLLEN *strlen_or_ind );
 
-SQLRETURN CLSetPos(
+SQLRETURN SQL_API CLSetPos(
            SQLHSTMT           statement_handle,
-           SQLUSMALLINT       irow,
+           SQLSETPOSIROW      irow,
            SQLUSMALLINT       foption,
            SQLUSMALLINT       flock );
 
-SQLRETURN CLSetScrollOptions(
+SQLRETURN SQL_API CLSetScrollOptions(
            SQLHSTMT           statement_handle,
            SQLUSMALLINT       f_concurrency,
-           SQLINTEGER         crow_keyset,
+           SQLLEN             crow_keyset,
            SQLUSMALLINT       crow_rowset );
 
-SQLRETURN CLSetStmtAttr( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLSetStmtAttr( SQLHSTMT statement_handle,
            SQLINTEGER attribute,
            SQLPOINTER value,
            SQLINTEGER string_length );
 
-SQLRETURN CLSetStmtOption( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLSetStmtOption( SQLHSTMT statement_handle,
            SQLUSMALLINT option,
-           SQLUINTEGER value );
+           SQLULEN value );
 
-SQLRETURN CLSpecialColumns( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLSpecialColumns( SQLHSTMT statement_handle,
            SQLUSMALLINT identifier_type,
            SQLCHAR *catalog_name,
            SQLSMALLINT name_length1,
@@ -482,7 +485,7 @@ SQLRETURN CLSpecialColumns( SQLHSTMT statement_handle,
            SQLUSMALLINT scope,
            SQLUSMALLINT nullable );
 
-SQLRETURN CLStatistics( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLStatistics( SQLHSTMT statement_handle,
            SQLCHAR *catalog_name,
            SQLSMALLINT name_length1,
            SQLCHAR *schema_name,
@@ -492,7 +495,7 @@ SQLRETURN CLStatistics( SQLHSTMT statement_handle,
            SQLUSMALLINT unique,
            SQLUSMALLINT reserved );
 
-SQLRETURN CLTablePrivileges(
+SQLRETURN SQL_API CLTablePrivileges(
            SQLHSTMT           statement_handle,
            SQLCHAR            *sz_catalog_name,
            SQLSMALLINT        cb_catalog_name,
@@ -501,7 +504,7 @@ SQLRETURN CLTablePrivileges(
            SQLCHAR            *sz_table_name,
            SQLSMALLINT        cb_table_name );
 
-SQLRETURN CLTables( SQLHSTMT statement_handle,
+SQLRETURN SQL_API CLTables( SQLHSTMT statement_handle,
            SQLCHAR *catalog_name,
            SQLSMALLINT name_length1,
            SQLCHAR *schema_name,
@@ -511,7 +514,7 @@ SQLRETURN CLTables( SQLHSTMT statement_handle,
            SQLCHAR *table_type,
            SQLSMALLINT name_length4 );
 
-SQLRETURN CLTransact( SQLHENV environment_handle,
+SQLRETURN SQL_API CLTransact( SQLHENV environment_handle,
            SQLHDBC connection_handle,
            SQLUSMALLINT completion_type );
 
@@ -524,7 +527,8 @@ int calculate_buffers( CLHSTMT cl_statement, int column_count );
 int free_bound_columns( CLHSTMT cl_statement );
 SQLRETURN do_fetch_scroll( CLHSTMT cl_statement,
             int fetch_orientation, 
-            int fetch_offset,
+            SQLLEN fetch_offset,
             SQLUSMALLINT *row_status_ptr,
-            SQLUINTEGER *rows_fetched_ptr );
+            SQLULEN *rows_fetched_ptr,
+			int ext_fetch );
 #endif
