@@ -21,11 +21,23 @@ int iniCommit( HINI hIni )
     if ( hIni == NULL )
         return INI_ERROR;
 
-	if ( hIni->bReadOnly )
+    if ( hIni->bReadOnly )
         return INI_ERROR;
 
     /* OPEN FILE */
-    hFile = uo_fopen( hIni->szFileName, "w" );
+
+#ifdef __OS2__
+    if (hIni->iniFileType == 0)
+    {
+#endif
+        hFile = uo_fopen( hIni->szFileName, "w" );
+#ifdef __OS2__
+    }
+    else
+    {
+        hFile = (FILE *)iniOS2Open (hIni->szFileName);
+    }
+#endif
     if ( !hFile )
         return INI_ERROR;
 
@@ -33,9 +45,17 @@ int iniCommit( HINI hIni )
 
     /* CLEANUP */
     if ( hFile != NULL )
-		uo_fclose( hFile );
+    {
+#ifdef __OS2__
+        if (hIni->iniFileType == 0)
+#endif
+		    uo_fclose( hFile );
+#ifdef __OS2__
+        else
+            iniOS2Close( hFile);
+#endif
+     }
 
     return INI_SUCCESS;
 }
 
-
