@@ -12,6 +12,17 @@
 #ifndef CAbout_included
 #define CAbout_included
 
+#ifdef QT_V4LAYOUT
+#define QT3_SUPPORT
+#include <Qt/qwidget.h>
+#include <Qt/qpixmap.h>
+#include <Qt/qlayout.h>
+#include <Qt/qmessagebox.h>
+#include <Qt/qlabel.h>
+#include <Qt/qpushbutton.h>
+#include <Qt/qframe.h>
+#include <Qt/qmovie.h>
+#else
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qlayout.h>
@@ -20,6 +31,7 @@
 #include <qpushbt.h>
 #include <qframe.h>
 #include <qmovie.h>
+#endif
 
 #include "CCredits.h"
 
