@@ -13,10 +13,18 @@
 #ifndef CFileDSN_included
 #define CFileDSN_included
 
+#ifdef QT_V4LAYOUT
+#define QT3_SUPPORT
+#include <Qt/qwidget.h>
+#include <Qt/qpushbutton.h>
+#include <Qt/qpixmap.h>
+#include <Qt/qlayout.h>
+#else
 #include <qwidget.h>
 #include <qpushbt.h>
 #include <qpixmap.h>
 #include <qlayout.h>
+#endif
 
 #include "CFileList.h"
 
