@@ -21,9 +21,12 @@
  *
  **********************************************************************
  *
- * $Id: diag.cpp,v 1.1.1.1 2001/10/17 16:40:30 lurcher Exp $
+ * $Id: diag.cpp,v 1.2 2007/02/12 11:49:37 lurcher Exp $
  *
  * $Log: diag.cpp,v $
+ * Revision 1.2  2007/02/12 11:49:37  lurcher
+ * Add QT4 support to existing GUI parts
+ *
  * Revision 1.1.1.1  2001/10/17 16:40:30  lurcher
  *
  * First upload to SourceForge
@@ -62,9 +65,15 @@
  **********************************************************************/
 
 #include <stdlib.h>
+#ifdef QT_V4LAYOUT
+#include <Qt/qapplication.h>
+#include <Qt/qmessagebox.h>
+#include <Qt/qlineedit.h>
+#else
 #include <qapplication.h>
 #include <qmessagebox.h>
 #include <qlineedit.h>
+#endif
 #include "diag.h"
 #include "odbctest.h"
 #include <sql.h>
