@@ -21,9 +21,16 @@
  *
  **********************************************************************
  *
- * $Id: env.cpp,v 1.2 2001/12/20 17:26:26 lurcher Exp $
+ * $Id: env.cpp,v 1.4 2007/02/12 11:49:37 lurcher Exp $
  *
  * $Log: env.cpp,v $
+ * Revision 1.4  2007/02/12 11:49:37  lurcher
+ * Add QT4 support to existing GUI parts
+ *
+ * Revision 1.3  2004/06/21 10:01:17  lurcher
+ *
+ * Fix a couple of 64 bit issues
+ *
  * Revision 1.2  2001/12/20 17:26:26  lurcher
  *
  * More warnings removed
@@ -79,6 +86,16 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef QT_V4LAYOUT
+#include <Qt/qapplication.h>
+#include <Qt/qmessagebox.h>
+#include <Qt/qpushbutton.h>
+#include <Qt/qcombobox.h>
+#include <Qt/qdialog.h>
+#include <Qt/qcheckbox.h>
+#include <Qt/qlabel.h>
+#include <Qt/qlineedit.h>
+#else
 #include <qapplication.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
@@ -87,6 +104,7 @@
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
+#endif
 #include <sql.h>
 #include <sqlext.h>
 #include "odbctest.h"
@@ -127,7 +145,7 @@ void dAllocHandle::Ok()
 SQLHANDLE out_handle, in_handle = SQL_NULL_HANDLE;
 SQLRETURN ret;
 SQLINTEGER type;
-char *handle;
+const char *handle;
 
 	switch( types -> currentItem())
 	{
